@@ -14,7 +14,8 @@ from doreah import caching
 from doreah.logging import log
 from doreah.regular import yearly, daily
 
-from .external import api_request_track, api_request_artist
+#from .external import api_request_track, api_request_artist
+from . import thirdparty
 from .__pkginfo__ import version
 from . import globalconf
 from .globalconf import datadir
@@ -291,8 +292,8 @@ def getTrackImage(artists,title,fast=False):
 	# fast request only retuns cached and local results, generates redirect link for rest
 	if fast: return "/image?title=" + urllib.parse.quote(title) + "&" + "&".join(["artist=" + urllib.parse.quote(a) for a in artists])
 
-	# non-fast lookup (esentially only the resolver lookup)
-	result = api_request_track((artists,title))
+	# non-fast lookup (essentially only the resolver lookup)
+	result = thirdparty.get_image_track_all((artists,title))
 
 	# cache results (even negative ones)
 	#cachedTracks[(frozenset(artists),title)] = result
@@ -345,8 +346,8 @@ def getArtistImage(artist,fast=False):
 	# fast request only retuns cached and local results, generates redirect link for rest
 	if fast: return "/image?artist=" + urllib.parse.quote(artist)
 
-	# non-fast lookup (esentially only the resolver lookup)
-	result = api_request_artist(artist=artist)
+	# non-fast lookup (essentially only the resolver lookup)
+	result = thirdparty.get_image_artist_all(artist)
 
 	# cache results (even negative ones)
 	#cachedArtists[artist] = result
